/**
 *****************************************************************************
 * Name: FlyweightDemo
 * Description: a simple demo for showing the use of Flyweight pattern in SAX
 * 
 * This code has no copyright. It is provided for didactical purposes only
 *
 *****************************************************************************
 */

import org.xml.sax.Parser;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.ParserFactory;
import java.io.FileInputStream;



/**
  * Demonstrate Flyweight Pattern in SAX
  *
  * <p>Usage: java -Dorg.xml.sax.parser=<var>CLASSNAME</var> FlyweightDemo
  * <var>FILE</var></p>
  *
  *
  * @see FlyweightFactory
  */
public class FlyweightDemo {

  /**
    * Main entry point.
    */
  public static void main (String args[])
    throws Exception
  {
    Parser parser;
    InputSource source;
    MusicHandler handler;
    FileInputStream input;

    if (args.length != 1) {
      System.err.println("Usage: java -Dorg.xml.sax.parser=<classname> " +
			 "FlyweightDemo <document>");
      System.exit(2);
    }

				// Allocate a SAX Parser object, using
				// the class name provided in the
				// org.xml.sax.parser property.
    parser = ParserFactory.makeParser();

				// Allocate an event handler, and register
				// it with the SAX parser for all four
				// types of events (we could use a 
				// separate object for each).
    handler = new MusicHandler();
    parser.setEntityResolver(handler);
    parser.setDTDHandler(handler);
    parser.setDocumentHandler(handler);
    parser.setErrorHandler(handler);

				// Create a Java FileInputStream from
				// the file: note that SAX cannot
				// use this directly.
    input = new FileInputStream(args[0]);

				// Create the input source.
    source = new InputSource(input);
    source.setSystemId(args[0]);

				// Parse the document from the
				// ByteStream.
    parser.parse(source);
  }

}



